==> scrollbars-0.5.0.tgz: package/src/index.js <==
"use strict";
var ScrollBars = (function () {
    /**
     * Create a new instance.
     *
     * @param  {string} selector
     */
    function ScrollBars(selector) {
        var _this = this;
        this.scrollbar = document.querySelector(selector);
        this.height(this.scrollbar);
        this.onScroll(this.scrollbar);
        this.onClick(this.scrollbar);
        window.addEventListener('resize', function () { return _this.height(_this.scrollbar); });
    }
    /**
     * Determine the height of the scrollbar.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    ScrollBars.prototype.position = function (element) {
        var ratio = (element.scrollTop / element.scrollHeight);
        //let percentage = ratio * (element.scrollTop / element.clientHeight);
        var data_scroll = Math.round(ratio * 1000);
        element.dataset['scroll'] = data_scroll.toString();
    };
    /**
     * Adjust the scroll bar height.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    ScrollBars.prototype.height = function (element) {
        var ratio = element.clientHeight / element.scrollHeight;
        var height = ratio * 100;
        var data_height = Math.floor(height);
        element.dataset['scrollBar'] = data_height.toString();
    };
    /**
     * On scroll event handler.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    ScrollBars.prototype.onScroll = function (element) {
        var _this = this;
        this.scrollbar.addEventListener('scroll', function (event) {
            _this.position(event.target);
            _this.height(event.target);
        });
    };
    /**
     * On click event handler.
     *
     * @param  {Element} element
     * @return {void}
     */
    ScrollBars.prototype.onClick = function (element) {
        var _this = this;
        element.addEventListener('click', function (e) {
            if (e.target !== element)
                return;
            if (e.target['offsetWidth'] - e.x < 30) {
                var click_percentage = Math.round((e.clientY / _this.scrollbar.clientHeight) * 100);
                var scroll_top = (_this.scrollbar.scrollHeight * click_percentage) / 100;
                _this.scrollbar.scrollTop = scroll_top;
            }
        });
    };
    ScrollBars.prototype.onDrag = function () { };
    return ScrollBars;
}());
module.exports = ScrollBars;

==> scrollbars-0.6.1.tgz: package/src/index.js <==
"use strict";
var Scrollbars = (function () {
    /**
     * Create a new instance.
     *
     * @param  {string} selector
     */
    function Scrollbars(selector) {
        var _this = this;
        this.scrollbar = document.querySelector(selector);
        this.height(this.scrollbar);
        this.onScroll(this.scrollbar);
        this.onClick(this.scrollbar);
        window.addEventListener('resize', function () { return _this.height(_this.scrollbar); });
    }
    /**
     * Determine the height of the scrollbar.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.position = function (element) {
        var ratio = (element.scrollTop / element.scrollHeight);
        var data_scroll = Math.round(ratio * 1000);
        element.dataset['scroll'] = data_scroll.toString();
    };
    /**
     * Adjust the scroll bar height.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.height = function (element) {
        var ratio = element.clientHeight / element.scrollHeight;
        var height = ratio * 100;
        var data_height = Math.floor(height);
        element.dataset['scrollBar'] = data_height.toString();
    };
    /**
     * Set the right margin of the scrolling element.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.margin = function (element) {
        element.style.marginRight = '-15px';
    };
    /**
     * On scroll event handler.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.onScroll = function (element) {
        var _this = this;
        this.scrollbar.addEventListener('scroll', function (event) {
            _this.position(event.target);
            _this.height(event.target);
        });
    };
    /**
     * On click event handler.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.onClick = function (element) {
        var _this = this;
        element.addEventListener('click', function (e) {
            if (e.target !== element)
                return;
            if (e.target['offsetWidth'] - e.x < 30) {
                var click_percentage = Math.round((e.clientY / _this.scrollbar.clientHeight) * 100);
                var scroll_top = (_this.scrollbar.scrollHeight * click_percentage) / 100;
                _this.scrollbar.scrollTop = scroll_top;
            }
        });
    };
    Scrollbars.prototype.onDrag = function (element) {
        element.addEventListener('click', function (e) {
            if (e.target !== element)
                return;
            if (e.target['offsetWidth'] - e.x < 30) {
            }
        });
    };
    return Scrollbars;
}());
var scrollbars = new Scrollbars('.scrollbars');
module.exports = Scrollbars;
